import * as i0 from '@angular/core';
import { Injectable, Pipe, EventEmitter, forwardRef, Component, Input, Output, ViewChild, HostListener, NgModule } from '@angular/core';
import * as i1 from '@angular/common/http';
import { HttpParams, HttpClientModule } from '@angular/common/http';
import { map, debounceTime, distinctUntilChanged } from 'rxjs/operators';
import proj4 from 'proj4';
import * as i4 from '@angular/forms';
import { NG_VALUE_ACCESSOR, FormsModule, ReactiveFormsModule } from '@angular/forms';
import * as i3 from '@acpaas-ui-widgets/ngx-location-viewer';
import { LocationViewerMap, NgxLocationViewerComponent, LocationViewerModule } from '@acpaas-ui-widgets/ngx-location-viewer';
import { Subject } from 'rxjs';
import * as i5 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i6 from '@acpaas-ui/ngx-icon';
import { IconModule } from '@acpaas-ui/ngx-icon';
import { MapService, LeafletModule } from '@acpaas-ui/ngx-leaflet';

/**
 * NgxLocationPickerHelper
 * Provide helper functions
 */
class NgxLocationPickerHelper {
    /**
     * NgxLocationPickerHelper constructor
     */
    constructor() {
        // These coordinates respresents border of Belgium
        this.minX = 49.4;
        this.maxX = 51.6;
        this.minY = 2.3;
        this.maxY = 6.45;
    }
    /**
     * Converts a query object to HttpParams.
     *
     * @param query (the object containing a set of parameters)
     *
     * @return HttpParams
     */
    toHttpParams(query) {
        const strQuery = this.queryObjectToStringObject(query);
        let params = new HttpParams();
        Object.keys(strQuery).forEach((key) => {
            if (strQuery[key]) {
                params = params.set(key, strQuery[key]);
            }
        });
        return params;
    }
    /**
     * Converts a query object to a query string
     *
     * @param obj (the object containing a set of parameters)
     *
     * @return any
     */
    queryObjectToStringObject(obj) {
        const retObj = {};
        Object.keys(obj).forEach((key) => {
            const queryValue = obj[key];
            if (typeof queryValue === "string") {
                retObj[key] = queryValue;
            }
            else if (Array.isArray(queryValue) && queryValue.length > 0) {
                const strArr = [];
                for (const [index, value] of queryValue.entries()) {
                    strArr.push(queryValue[index].toString());
                }
                retObj[key] = strArr;
            }
            else {
                retObj[key] =
                    queryValue !== null && queryValue !== undefined
                        ? queryValue.toString()
                        : "";
            }
        });
        return retObj;
    }
    /**
     * Normalize search value
     *
     * @return string
     */
    normalizeSearchValue(value) {
        if (!this.isCoordinate(value)) {
            // Remove malicious characters
            const maliciousCharacters = /[\*\%\;\|\<\>\{\}\[\]\/\\\n\r\?\.]/g;
            value = value.replace(maliciousCharacters, "");
            const hasBrackets = value.match(/\(.*?\)/);
            if (hasBrackets && hasBrackets.length)
                return value.replace(` ${hasBrackets}`, "");
        }
        return value;
    }
    /**
     * Determines if the given query input resembles an address or not.
     *
     * @return boolean
     */
    isAddress(query, locationKeywords) {
        if (!query || query.trim().length === 0)
            return false;
        const lowerQuery = query.toLowerCase();
        // Check if it contains a known location keyword explicitly (exclude such cases)
        const lowerLocationKeywords = locationKeywords.map(k => k.toLowerCase());
        if (lowerLocationKeywords.some(keyword => lowerQuery.includes(keyword))) {
            return false;
        }
        // Ensure the query matches: Street name (1 or more words) + house number
        const addressPattern = /^\b([\p{L}'\-]{2,}(?:\s+[\p{L}'\-]{2,})*)\s+(\d+[a-zA-Z]{0,5})(?:,\s*(\d{1,4}|\d{4,5}(?:\s+[\p{L}\s]+)?|[\p{L}\s]+)?)?\s*,?\s*$/iu;
        // Match only if there is at least one street name and a house number
        return addressPattern.test(query);
    }
    /**
     * Determines if the given query input resembles coordinate pairs
     *
     * @return boolean
     */
    isCoordinate(query) {
        const coordinateParts = query && query.trim().length > 0 ? query.split(",") : null;
        if (coordinateParts.length === 2) {
            if (!isNaN(Number(coordinateParts[0])) &&
                !isNaN(Number(coordinateParts[1]))) {
                return true;
            }
        }
        return false;
    }
    /**
     * Determines if the given object matches LocationModel interface
     *
     *
     */
    isLocationModel(object) {
        return "streetName" in object;
    }
    /**
     * Determines if the given query input resembles alternative coordinate pairs ex: 51,205729 4,388629
     *
     * @return boolean
     */
    isAlternativeCoordinateNotation(query) {
        const coordinateParts = query && query.trim().length > 0 ? query.split(" ") : null;
        if (coordinateParts.length === 2) {
            if (!isNaN(Number(coordinateParts[0].replace(",", "."))) &&
                !isNaN(Number(coordinateParts[1].replace(",", ".")))) {
                return true;
            }
        }
        return false;
    }
    convertAlternativeCoordinateToNormalNotation(query) {
        const commaChar = /\,/gi;
        const spaceChar = / /gi;
        return query.replace(commaChar, ".").replace(spaceChar, ",");
    }
    /**
     * Splits the location query in street name and house number and checks for streetnameid.
     *
     * @return streetAndNumber
     */
    buildAddressQuery(query, selectedLocation, onlyAntwerp, countryCodes, buffer, coordinateSearch, streetIds) {
        const streetAndNumber = {
            streetname: "",
            streetids: streetIds ?? [],
            housenumber: "",
            postcode: "",
            place: "",
            onlyAntwerp: onlyAntwerp,
            countries: countryCodes,
            buffer: buffer,
            xcoord: coordinateSearch?.lat,
            ycoord: coordinateSearch?.lng
        };
        const allParts = query && query.trim().length > 0 ? query.split(",") : null;
        let postcodeAndMunicipalityParts = null;
        let addressParts = null;
        if (allParts) {
            addressParts = allParts[0].split(" ");
            if (allParts.length == 2) {
                postcodeAndMunicipalityParts = allParts[1].split(" ");
            }
        }
        if (addressParts) {
            let foundHouseNumber = false;
            addressParts.map((part, index) => {
                const isNumber = /^[0-9]/.test(part);
                const isHouseNumberPart = /[0-9]\w?$/.test(part);
                // Check if we found the house number
                if (isNumber && !foundHouseNumber) {
                    streetAndNumber.housenumber = part;
                    foundHouseNumber = true;
                }
                else if (foundHouseNumber) {
                    // Continue building the house number if still adding
                    streetAndNumber.housenumber += part;
                }
                else {
                    // Otherwise, treat it as part of the street name
                    if (streetAndNumber.streetname) {
                        streetAndNumber.streetname += " ";
                    }
                    streetAndNumber.streetname += part;
                }
            });
            streetAndNumber.streetname = streetAndNumber.streetname
                .trim()
                .replace(/\s+\([a-z\s\,]+\)$/gi, "");
            if (/[a-z]\d*$/.test(streetAndNumber.streetname)) {
                streetAndNumber.streetname = streetAndNumber.streetname.replace(/[0-9]*$/g, "");
            }
            // Clean up street name
            streetAndNumber.streetname = streetAndNumber.streetname
                .trim()
                .replace(/\s+\([a-z\s\,]+\)$/gi, "");
            // Edge case: Remove numbers mistakenly left in street name
            if (/[a-z]\d*$/.test(streetAndNumber.streetname)) {
                streetAndNumber.streetname = streetAndNumber.streetname.replace(/[0-9]*$/g, "");
            }
            streetAndNumber.housenumber = streetAndNumber.housenumber.trim();
            // The user first chooses a street and can then add a house number. The address is looked up based on the streetnameid and house number.
            // The combination of a street name id and a house number are unique to Antwerp.
            // Including a street name has no added value if the housenumer and streetnameid are known
            if (streetAndNumber.onlyAntwerp && streetAndNumber.streetids.length !== 0 && streetAndNumber.housenumber)
                streetAndNumber.streetname = null;
        }
        if (postcodeAndMunicipalityParts) {
            postcodeAndMunicipalityParts = postcodeAndMunicipalityParts.filter(p => p && p.trim().length > 0);
            postcodeAndMunicipalityParts.forEach((part) => {
                const trimmedPart = part.trim();
                if (/^\d{1,4}$/.test(trimmedPart)) {
                    streetAndNumber.postcode = trimmedPart;
                }
                else {
                    // Assume it's part of the municipality/place name
                    if (streetAndNumber.place) {
                        streetAndNumber.place += " ";
                    }
                    streetAndNumber.place += trimmedPart;
                }
            });
            streetAndNumber.place = streetAndNumber.place?.trim();
        }
        // if previous selected location is of type LocationModel and location has streetid
        //  ==> check if name corresponds with the streetname to use the streetnameid
        if (selectedLocation &&
            this.isLocationModel(selectedLocation) &&
            selectedLocation.streetNameId) {
            if (selectedLocation.streetName.toUpperCase() ===
                streetAndNumber.streetname.toUpperCase()) {
                streetAndNumber.streetname = null;
                streetAndNumber.streetids.push(selectedLocation.streetNameId);
            }
        }
        return streetAndNumber;
    }
    /**
     * Splits the location query in X/Y coordinate.
     *
     * @return coordinate
     */
    extractXYCoord(query) {
        const coordinateParts = query && query.trim().length > 0 ? query.split(",") : null;
        const coordinate = {
            x: Number(coordinateParts[0]),
            y: Number(coordinateParts[1]),
        };
        return coordinate;
    }
    /**
     * Checks wether given coordinates are WGS84 (response true) or Lambert (response false)
     *
     * @param x given x coordinate
     * @param y given y coordinate
     *
     * @return isWgs84
     */
    isWgs84Coordinates(x, y) {
        if (x >= this.minX && x <= this.maxX && y >= this.minY && y <= this.maxY) {
            return true;
        }
        return false;
    }
    /**
     * Converts lambertcoordinates to wgs84 coordinate
     *
     * @param lambertCoordinate lambertmodel coordinates
     *
     * @return wgs84coordinates
     */
    convertLambertToWgs84Coordinates(lambertCoordinate) {
        // eslint-disable-next-line max-len
        const lambertProj = "+proj=lcc +lat_1=51.16666723333333 +lat_2=49.8333339 +lat_0=90 +lon_0=4.367486666666666 +x_0=150000.013 +y_0=5400088.438 +ellps=intl +towgs84=-106.869,52.2978,-103.724,0.3366,-0.457,1.8422,-1.2747 +units=m +no_defs";
        const result = proj4(lambertProj, "WGS84", [
            lambertCoordinate.x,
            lambertCoordinate.y,
        ]);
        const coordinates = {
            x: result[0] >= this.minX && result[0] <= this.maxX
                ? result[0]
                : result[1] >= this.minX && result[1] <= this.maxX
                    ? result[1]
                    : 0,
            y: result[0] >= this.minY && result[0] <= this.maxY
                ? result[0]
                : result[1] >= this.minY && result[1] <= this.maxY
                    ? result[1]
                    : 0,
        };
        return coordinates;
    }
}
/** @nocollapse */ NgxLocationPickerHelper.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: NgxLocationPickerHelper, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
/** @nocollapse */ NgxLocationPickerHelper.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: NgxLocationPickerHelper, providedIn: "root" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: NgxLocationPickerHelper, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: "root",
                }]
        }], ctorParameters: function () { return []; } });

/**
 * NgxLocationPickerService
 * Provide functions for handling location or address searches
 */
class NgxLocationPickerService {
    /**
     * NgxLocationPickerService constructor
     *
     * @param httpClient (httpClient used for making requests to the api)
     * @param locationPickerHelper (Helper functions class)
     */
    constructor(httpClient, locationPickerHelper) {
        this.httpClient = httpClient;
        this.locationPickerHelper = locationPickerHelper;
        this.locationPickerApi = '';
    }
    /**
     * Main search function. Determines which action to undertake based on the provided search string.
     *
     * @param delegateSearch (the delegateSearch model)
     *
     * @return Observable<LocationModel[] | AddressModel[] | CoordinateModel[]>
     */
    delegateSearch(delegateSearch) {
        delegateSearch.prioritizelayer = delegateSearch.prioritizelayer ? delegateSearch.prioritizelayer : ['straatnaam'];
        this.locationPickerApi = delegateSearch.baseUrl;
        if (this.locationPickerHelper.isCoordinate(delegateSearch.search)) {
            const coordinate = this.locationPickerHelper.extractXYCoord(delegateSearch.search);
            const requestQuery = {
                xcoord: coordinate.x,
                ycoord: coordinate.y,
                returnsingle: delegateSearch.cascadingCoordinateReturnSingle,
                totalresults: delegateSearch.cascadingCoordinateLimit,
                cascadingRules: delegateSearch.cascadingCoordinateRules,
                cascadingGuid: delegateSearch.cascadingCoordinateGuid,
                buffer: delegateSearch.bufferSearch,
            };
            return this.searchLocationsByCoordinates(requestQuery);
        }
        else if (this.locationPickerHelper.isAddress(delegateSearch.search, delegateSearch.locationKeywords)) {
            const addressQuery = this.locationPickerHelper.buildAddressQuery(delegateSearch.search, delegateSearch.selectedLocation, delegateSearch.onlyAntwerp, delegateSearch.countryCodes, delegateSearch.bufferSearch, delegateSearch.coordinateSearch, delegateSearch?.selectedLocation && delegateSearch?.selectedLocation?.streetNameId ? [delegateSearch?.selectedLocation?.streetNameId] : delegateSearch.selectedLocation && delegateSearch?.selectedLocation?.street?.streetNameId ? [delegateSearch?.selectedLocation?.street?.streetNameId] : []);
            if (delegateSearch.searchStreetNameForAddress) {
                const locationQuery = {
                    layers: ['straatnaam'],
                    pagesize: delegateSearch.limit,
                    search: addressQuery.streetname,
                    prioritizelayer: delegateSearch.prioritizelayer,
                    sort: delegateSearch.sort,
                    onlyAntwerp: delegateSearch.onlyAntwerp,
                    countries: delegateSearch.countryCodes,
                    buffer: delegateSearch.bufferSearch,
                    xcoord: delegateSearch.coordinateSearch?.lat,
                    ycoord: delegateSearch.coordinateSearch?.lng,
                };
                return this.searchLocations(locationQuery);
            }
            else {
                return this.searchAddresses(addressQuery);
            }
        }
        else {
            const locationQuery = {
                layers: delegateSearch.layers,
                pagesize: delegateSearch.limit,
                search: delegateSearch.search,
                prioritizelayer: delegateSearch.prioritizelayer,
                sort: delegateSearch.sort,
                onlyAntwerp: delegateSearch.onlyAntwerp,
                countries: delegateSearch.countryCodes,
                buffer: delegateSearch.bufferSearch,
                xcoord: delegateSearch.coordinateSearch?.lat,
                ycoord: delegateSearch.coordinateSearch?.lng,
            };
            return this.searchLocations(locationQuery);
        }
    }
    /**
     * Returns a list of layers present in elastic.
     *
     * @return Observable<LayerModel[]>
     */
    getLayers() {
        return this.httpClient
            .get(`${this.locationPickerApi}/layers`)
            .pipe(map((pagedResult) => pagedResult._embedded.layers));
    }
    /**
     * Search locations by user input
     *
     * @param query (the location to look for)
     *
     * @return Observable<LocationModel[]>
     */
    searchLocations(query) {
        const parameters = this.locationPickerHelper.toHttpParams(query);
        return this.httpClient
            .get(`${this.locationPickerApi}/locations`, { params: parameters })
            .pipe(map((pagedResult) => pagedResult._embedded.locations));
    }
    /**
     * Search addresses based on street name and house number
     *
     * @param query (the address to look for, consists of a street name and house number)
     *
     * @return Observable<AddressModel[]>
     */
    searchAddresses(query) {
        const parameters = this.locationPickerHelper.toHttpParams(query);
        return this.httpClient
            .get(`${this.locationPickerApi}/addresses`, { params: parameters })
            .pipe(map((pagedResult) => pagedResult._embedded.addresses));
    }
    /**
     * Get an address by id
     *
     * @param query (the address id to get)
     *
     * @return Observable<AddressModel[]>
     */
    searchAddressById(query) {
        const parameters = this.locationPickerHelper.toHttpParams(query);
        return this.httpClient.get(`${this.locationPickerApi}/addresses/${query.id}`, { params: parameters });
    }
    /**
     * Search locations based on a set of coordinates
     *
     * @param query (search query containing coordinates and other parameters)
     *
     * @return Observable<CoordinateModel[]>
     */
    searchLocationsByCoordinates(query) {
        return this.httpClient
            .post(`${this.locationPickerApi}/coordinates/search`, query)
            .pipe(map((result) => result.results));
    }
}
/** @nocollapse */ NgxLocationPickerService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: NgxLocationPickerService, deps: [{ token: i1.HttpClient }, { token: NgxLocationPickerHelper }], target: i0.ɵɵFactoryTarget.Injectable });
/** @nocollapse */ NgxLocationPickerService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: NgxLocationPickerService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: NgxLocationPickerService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.HttpClient }, { type: NgxLocationPickerHelper }]; } });

class HighlightSearchDirective {
    transform(value, args) {
        if (!args) {
            return value;
        }
        try {
            const regEx = new RegExp(args, 'ig');
            return value.replace(regEx, (match) => `<strong>${match}</strong>`);
        }
        catch (e) {
            // We do nothing.
        }
    }
}
/** @nocollapse */ HighlightSearchDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: HighlightSearchDirective, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
/** @nocollapse */ HighlightSearchDirective.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: HighlightSearchDirective, name: "highlight" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: HighlightSearchDirective, decorators: [{
            type: Pipe,
            args: [{
                    name: 'highlight'
                }]
        }] });

class NgxLocationPickerComponent {
    get selectedLocation() {
        return this._selectedLocation;
    }
    set selectedLocation(location) {
        if (this.mapLoaded &&
            location &&
            location.position &&
            location.position.lat &&
            location.position.lng) {
            this.resetLocationSearchFields();
            this.setInitialLocation(location);
            delete location.options;
            location = {
                ...location,
                actualLocation: location.position,
            };
        }
        this._selectedLocation = location;
        this.propagateChange(this._selectedLocation);
    }
    get selectedLocationLabel() {
        return this._selectedLocation?.label || '';
    }
    set selectedLocationLabel(value) {
        if (this._selectedLocation) {
            this._selectedLocation.label = value;
        }
    }
    /**
     * Checks if input field has a value
     */
    get inputHasValue() {
        return this.selectedLocation && !this.selectedLocation.label;
    }
    /**
     * Checks if foundLocations array has items.
     */
    get hasResults() {
        return this.foundLocations && this.foundLocations.length > 0;
    }
    /**
     * NgxLocationPickerComponent constructor, injects required dependencies
     */
    constructor(locationPickerService, locationPickerHelper, locationViewerService, renderer) {
        this.locationPickerService = locationPickerService;
        this.locationPickerHelper = locationPickerHelper;
        this.locationViewerService = locationViewerService;
        this.renderer = renderer;
        /* The default zoom level on map load. */
        this.defaultZoom = 14;
        /**
         *  The zoom level when a location is selected.
         *  If null the zoomlevel won't change after location selection.
         */
        this.onSelectZoom = 16;
        /* The zoom level will change after location selected (to fit selected geometry). */
        this.changeZoomLevelOnLocationSelect = false;
        /* The initial map center on load. */
        this.mapCenter = [51.215, 4.425];
        /* Show a sidebar next to the map leaflet. A sidebar can contain any additional info you like. */
        this.hasSidebar = false;
        /* Show or hide the map. */
        this.showMap = true;
        /* Toggle the clear button */
        this.showClearInputButton = true;
        /**
         * Add layers to show on the map. eg: A-card terminals, Velo stations, ...
         * A single featureLayer consists of:
         *
         * url: the url to the mapServer containing the features to be shown on the map.
         * icon: the marker to use to show featureLayer locations.
         *
         * An icon should include: Streamline icon class, the icon color (default: #0064B) and the icon size (default: 40px)
         * see: FeatureLayerIconModel
         */
        this.featureLayers = [];
        /* The input field placeholder text. */
        this.placeholder = "Zoek een locatie…";
        /* Label to use when no results were found. */
        this.noResultsLabel = "Er werd geen gekende locatie gevonden.";
        /* Label to use for "use selected coordinates option" */
        this.defaultOptionLabel = "Gebruik gekozen coördinaat";
        /* Aria label for clear input button. */
        this.clearInputAriaLabel = "Tekstveld leegmaken";
        /* Aria label for picking a location on the map */
        this.locationPickAriaLabel = "Kies een locatie op de map";
        /* Aria label for zooming in */
        this.zoomInAriaLabel = "Zoom in";
        /* Aria label for zooming out  */
        this.zoomOutAriaLabel = "Zoom out";
        /* Aria label for text input */
        this.textInputAriaLabel = "Locaties zoeken op basis van zoekterm";
        /* Aria label for locate me button */
        this.locateMeAriaLabel = "Gebruik mijn locatie";
        /* Aria label for locate me button when fetching */
        this.locatingAriaLabel = "Locatie bepalen";
        /* Locate me error notification texts */
        this.locateMeNotSupportedNotification = "Locatiebepaling wordt niet ondersteund op dit toestel.";
        this.locateMeNotAllowedNotification = "Gelieve toegang tot je locatie toe te staan.";
        this.locateMeUnavailableNotification = "Je locatie kon niet worden bepaald.";
        this.locateMeTimeoutNotification = "Het duurde te lang om je locatie te bepalen.";
        this.locateMeUnknownNotification = "Er trad een onbekende fout op bij het bepalen van je locatie.";
        /* No/invalid coordinate error notification text */
        this.coordinateErrorNotification = "Locatie kan niet op de map getoond worden.";
        /* Zoom info notification text */
        this.zoomInfoNotification = "Gebruik de Shift toets om te zoomen door te scrollen.";
        /* Default tile layer button label */
        this.defaultTileLayerLabel = "Kaart";
        /* Sets the LocationPicker up to accept Vector based layer, instead of Raster based (default Raster based). */
        this.tileLayerIsVectorBased = false;
        /* Search input length requirement before triggering a search. */
        this.minInputLength = 2;
        /* The amount of results to return */
        this.locationsLimit = 5;
        /* The layers to search locations for, 'all' to search in all the layers, 'none' to disable location search */
        this.locationLayers = ["straatnaam"];
        /**
         * Prioritize specific layers, boosts results from given layers to the top of the found locations.
         * The order of the values in the array determines the priority. Overrides sortBy.
         */
        this.prioritizeLayers = ["straatnaam"];
        /* Sort locations by certain key. */
        this.sortBy = "";
        /* Search locations and addresses inside Antwerp otherwise will search in provided countries ==> countryCodes */
        this.onlyAntwerp = true;
        /* Search locations and addresses in provided country codes if 'onlyAntwerp' is false */
        this.countryCodes = ["be", "nl", "lu"];
        /* Use geolocation when the component finished loading */
        this.locateUserOnInit = false;
        /* Set time to wait after user stops typing before triggering a search */
        this.debounceTime = 400;
        /* whether or not to return a single cascading result */
        this.cascadingCoordinateReturnSingle = true;
        /* Limit total cascading result, useful when returnSingle is false */
        this.cascadingCoordinateLimit = 10;
        /* Cascading configuration for doing reverse lookups by coordinates
        Will NOT be used if a valid and matching cascadingCoordinateGuid is given */
        this.cascadingCoordinateRules = [];
        /* Shows layermangement inside the sidebar. Layermanagement is used to add or remove featurelayers. */
        this.showLayerManagement = false;
        /* Show selection tools */
        this.showSelectionTools = false;
        /* Show measure tools */
        this.showMeasureTools = false;
        /* show whatishere button */
        this.showWhatIsHereButton = false;
        /* If provided, adds coordinate to resultList at index */
        this.addCoordinateToResultsAt = null;
        /* If search string contains one of these words, search for locations instead of address */
        this.locationKeywords = ["kaainummer"];
        /* When entering address search for streetname instead, will search for locations with provided streetname */
        this.searchStreetNameForAddress = false;
        /* If provided, When searching for current position*/
        this.positionOptions = {
            enableHighAccuracy: false,
            timeout: Infinity,
            maximumAge: 0,
            preferredAccuracy: 25,
            trackingTimeout: 2000,
        };
        /* If true, will use watchposition to track current position */
        this.trackPosition = false;
        /* AddPolygon event */
        this.addPolygon = new EventEmitter();
        /* AddLine event */
        this.addLine = new EventEmitter();
        /* EditFeature event */
        this.editFeature = new EventEmitter();
        /* LocationSelect event: fired when selecting a location. */
        this.locationSelect = new EventEmitter();
        /* Operational layer filtered: fired when using selection tools rectangle/polygon, using filter layer or clicking on marker of operational layer*/
        this.filteredResult = new EventEmitter();
        /* Whether a search request is running or not. */
        this.searching = false;
        /* Whether a search was initiated or not. */
        this.didSearch = false;
        /* Whether the user clicked the pick location from map button or not. */
        this.pickLocationActive = false;
        /* Keeps track whether the search was triggered by picking a location on the map */
        this.pickedLocation = false;
        /* Whether we're locating a user or not */
        this.isLocating = false;
        /* The locations returned from the server. */
        this.foundLocations = [];
        /* The current highlighted index in the location results array */
        this.highlightedLocationResult = 0;
        /* Input change subject */
        this.searchQueryChanged = new Subject();
        /* Current leaflet state */
        this.mapLoaded = false;
        /* Currently selected location */
        this._selectedLocation = {};
        /* Cursor state if hovering over leaflet or not */
        this.cursorOnLeaflet = false;
        /* Used for ControlValueAccessor */
        this.propagateChange = (_) => { };
        this.inputChangeSubscription = this.searchQueryChanged
            .pipe(debounceTime(this.debounceTime), distinctUntilChanged())
            .subscribe((query) => {
            this.onSearch(query);
        });
    }
    /**
     * On component init
     */
    ngOnInit() {
        /* if baseUrl is not set, throw an error. */
        if (!this.baseUrl) {
            throw new Error("baseUrl parameter is missing. Please pass in your BFF url.");
        }
        /* Only initialise leaflet map when it's required. */
        if (this.showMap) {
            this.initLocationPicker();
        }
    }
    /**
     * On component destroy
     */
    ngOnDestroy() {
        /* Unsubscribe input change subscription on component destroy */
        if (this.inputChangeSubscription) {
            this.inputChangeSubscription.unsubscribe();
        }
        /* Unsubscribe locationService subscription on component destroy */
        if (this.locationServiceSubscription) {
            this.locationServiceSubscription.unsubscribe();
        }
        this.clearWatch();
    }
    /**
     * Writes a new value to the element.
     */
    writeValue(location, reset = false) {
        if (reset) {
            this.resetLocationSearchFields();
            this.selectedLocation = {};
            this.locationSelect.emit(location);
        }
        if ((location && location.label) ||
            (location && location.position && location.position.wgs84)) {
            // adds space to label if layer is streetname so user can search for address just by adding housenumber
            if (location && location.layer && location.layer === "straatnaam") {
                location.label = `${location.label} `;
                this.leafletSearchField.nativeElement.focus();
            }
            this.selectedLocation = location;
            // update previousLocation on new search selectedLocation changes to search query and needs to know previous result for address search
            this.previousLocation = location;
            this.locationSelect.emit(location);
        }
    }
    /**
     * Registers a callback function that is called when the control's value changes in the UI.
     */
    registerOnChange(fn) {
        this.propagateChange = fn;
    }
    /**
     * Registers a callback function is called by the forms API on initialization to update the form model on blur.
     */
    registerOnTouched() { }
    /**
     * Zooms the map in
     */
    zoomIn() {
        this.leafletMap.zoomIn();
    }
    /**
     * Zooms the map out
     */
    zoomOut() {
        this.leafletMap.zoomOut();
    }
    /**
     * On input change event
     */
    onInputChange(query) {
        this.searchQueryChanged.next(query);
    }
    /**
     * Clear search field value, If map is visible, resets to it's original position.
     */
    emptyField() {
        this.writeValue({}, true);
        if (this.showMap) {
            this.removeGeometry();
            this.removeMarker();
        }
    }
    /**
     * Allows location search by clicking somewhere on the map.
     */
    pickLocationOnMap() {
        if (this.pickLocationActive) {
            this.cancelPickingEvents();
        }
        else {
            this.leafletMap.map.addEventListener("click", (event) => this.registerMapClick(event));
            if (this.leafletMap.operationalLayer) {
                this.leafletMap.operationalLayer.removeEventListener("click");
            }
        }
        this.pickLocationActive = !this.pickLocationActive;
    }
    /**
     * Tries to determine the current users position
     */
    getDeviceLocation() {
        this.isLocating = true;
        // if we use trackposition we will search until we have an accurate coordinate
        if (navigator && navigator.geolocation) {
            // start watching position for high accuracy
            this.geoLocateId = navigator.geolocation.watchPosition((position) => {
                this.cachedPosition = position;
                // depending on conditions we check if need to keep searching
                const keepSearching = this.cachedPosition.coords.accuracy >
                    this.positionOptions.preferredAccuracy;
                if (this.trackPosition && keepSearching) {
                    if (this.clearWatchTimeoutId == null) {
                        this.clearWatchTimeoutId = setTimeout(() => {
                            this.searchWithCachedPosition();
                            this.clearWatch();
                        }, this.positionOptions.trackingTimeout);
                    }
                    this.showProximityCircle([position.coords.latitude, position.coords.longitude], position.coords.accuracy);
                }
                else {
                    this.searchWithCachedPosition();
                    this.clearWatch();
                }
            }, (error) => {
                this.isLocating = false;
                let message = "";
                switch (error.code) {
                    case 1:
                        message = this.locateMeNotAllowedNotification;
                        break;
                    case 2:
                        message = this.locateMeUnavailableNotification;
                        break;
                    case 3:
                        message = this.locateMeTimeoutNotification;
                        break;
                    default:
                        message = this.locateMeUnknownNotification;
                        break;
                }
                this.setNotification({
                    status: "danger",
                    text: message,
                    icon: "ai-alert-triangle",
                });
            }, this.positionOptions);
        }
        else {
            this.setNotification({
                status: "danger",
                text: this.locateMeNotSupportedNotification,
                icon: "ai-alert-triangle",
            });
        }
    }
    /**
     * Trigger search when input string is longer than 2 characters
     */
    onSearch(searchValue, forcedCoordinateSearch = false) {
        this.leafletNotification = null;
        this.highlightedLocationResult = 0;
        this.cancelGeolocation();
        if (searchValue && this.locationPickerHelper.isAlternativeCoordinateNotation(searchValue))
            searchValue = this.locationPickerHelper.convertAlternativeCoordinateToNormalNotation(searchValue);
        if (searchValue && !this.locationPickerHelper.isCoordinate(searchValue))
            this.pickedLocation = false;
        if (forcedCoordinateSearch)
            this.pickedLocation = true;
        if (!searchValue.trim())
            this.emptyField();
        if (searchValue.length >= this.minInputLength && (this.locationPickerHelper.isAddress(searchValue, this.locationKeywords)
            || this.locationPickerHelper.isCoordinate(searchValue) || !this.locationLayers.includes("none"))) {
            this.searching = true;
            this.didSearch = true;
            if (this.locationPickerHelper.isCoordinate(searchValue) && !this.pickLocationActive) {
                let coords = this.locationPickerHelper.extractXYCoord(searchValue);
                const tempLocation = {
                    position: { wgs84: { lat: coords.x, lng: coords.y } },
                    label: `${coords.x},${coords.y}`,
                    actualLocation: { lat: coords.x, lng: coords.y },
                };
                if (!this.locationPickerHelper.isWgs84Coordinates(coords.x, coords.y)) {
                    coords = this.locationPickerHelper.convertLambertToWgs84Coordinates(coords);
                    searchValue = `${coords.x}, ${coords.y}`;
                }
                this.addMapMarker([coords.x, coords.y], null, false, false, this.createPinMarker());
                this.writeValue(tempLocation);
            }
            searchValue = this.locationPickerHelper.normalizeSearchValue(searchValue);
            // Reset the previous location if the current search value does not equal the previous one, only applicable to addresses and locations.
            if (((this.previousLocation && 'formattedAddress' in this.previousLocation && !this.inputStringEqualsSelectedStreetName(searchValue, this.previousLocation?.street?.streetName))
                || (this.previousLocation && 'position' in this.previousLocation && !this.inputStringEqualsSelectedStreetName(searchValue, this.previousLocation?.name))) && !this.locationPickerHelper.isCoordinate(searchValue))
                this.previousLocation = null;
            const delegateSearch = {
                search: searchValue,
                baseUrl: this.baseUrl,
                limit: this.locationsLimit,
                layers: this.locationLayers,
                prioritizelayer: this.prioritizeLayers,
                sort: this.sortBy,
                cascadingCoordinateReturnSingle: this.cascadingCoordinateReturnSingle,
                cascadingCoordinateLimit: this.cascadingCoordinateLimit,
                cascadingCoordinateRules: this.cascadingCoordinateRules,
                cascadingCoordinateGuid: this.cascadingCoordinateGuid,
                selectedLocation: this.previousLocation,
                locationKeywords: this.locationKeywords,
                searchStreetNameForAddress: this.searchStreetNameForAddress,
                onlyAntwerp: this.onlyAntwerp,
                countryCodes: this.countryCodes,
                bufferSearch: this.bufferSearch,
                coordinateSearch: this.coordinateSearch,
            };
            this.locationServiceSubscription = this.locationPickerService
                .delegateSearch(delegateSearch)
                .subscribe((response) => {
                this.foundLocations = response;
                //adds used coordinate to result list
                if (this.addCoordinateToResultsAt && this.pickedLocation) {
                    this.foundLocations.splice(this.addCoordinateToResultsAt, 0, this.previousLocation);
                }
                if (this.foundLocations.length && this.pickedLocation) {
                    this.onLocationSelect(null, this.foundLocations[0], true);
                }
            }, (error) => {
                console.log(error);
            }, () => {
                this.searching = false;
            });
        }
    }
    setDidSearch() {
        setTimeout(() => this.didSearch = false, 200);
    }
    /**
     * When a location is selected from the list.
     */
    onLocationSelect($event, selectedLocation, didSearch = false) {
        if ($event)
            $event.preventDefault();
        this.didSearch = didSearch;
        this.removeMarker(true);
        this.writeValue(selectedLocation);
        if (this.showMap) {
            if (selectedLocation.address &&
                selectedLocation.address.addressPosition &&
                selectedLocation.address.addressPosition.wgs84) {
                const coords = [
                    selectedLocation.address.addressPosition.wgs84.lat,
                    selectedLocation.address.addressPosition.wgs84.lng,
                ];
                this.addResultMarker(coords, { color: "var(--THEME1-600)", opacity: "40", strokeColor: "var(--THEME1-600)", strokeWidth: "2px" });
            }
            else if (selectedLocation.addressPosition && selectedLocation.addressPosition.wgs84) {
                const coords = [
                    selectedLocation.addressPosition.wgs84.lat,
                    selectedLocation.addressPosition.wgs84.lng,
                ];
                this.addResultMarker(coords, { color: "var(--THEME1-600)", opacity: "40", strokeColor: "var(--THEME1-600)", strokeWidth: "2px" });
            }
            else if (selectedLocation.position) {
                if (selectedLocation.label && selectedLocation.position.geometry && selectedLocation.position.geometryShape) {
                    this.addMapGeoJson(selectedLocation.label, selectedLocation.position.geometryShape, selectedLocation.position.geometry);
                }
                else if (selectedLocation.position.wgs84) {
                    const coords = [
                        selectedLocation.position.wgs84.lat,
                        selectedLocation.position.wgs84.lng,
                    ];
                    this.addResultMarker(coords, { color: "var(--THEME1-600)", opacity: "40", strokeColor: "var(--THEME1-600)", strokeWidth: "2px" });
                }
            }
            else if (selectedLocation.location &&
                selectedLocation.location.position &&
                (selectedLocation.location.position.geometry || selectedLocation.location.position.wgs84)) {
                if (selectedLocation.label && selectedLocation.location.position.geometry && selectedLocation.location.position.geometryShape && selectedLocation.location.position.geometryShape !== "Point") {
                    this.addMapGeoJson(selectedLocation.label, selectedLocation.location.position.geometryShape, selectedLocation.location.position.geometry);
                }
                else {
                    let coords;
                    if (selectedLocation.layerAttributes?.Position_wgs84_lat !== undefined &&
                        selectedLocation.layerAttributes?.Position_wgs84_lon !== undefined) {
                        coords = [
                            selectedLocation.layerAttributes.Position_wgs84_lat,
                            selectedLocation.layerAttributes.Position_wgs84_lon,
                        ];
                    }
                    else {
                        coords = [
                            selectedLocation.location.position.wgs84.lat,
                            selectedLocation.location.position.wgs84.lng,
                        ];
                    }
                    this.addResultMarker(coords, { color: "var(--THEME1-600)", opacity: "40", strokeColor: "var(--THEME1-600)", strokeWidth: "2px" });
                }
            }
            else {
                this.removeGeometry();
                this.removeMarker();
                this.setNotification({
                    status: "danger",
                    text: this.coordinateErrorNotification,
                    icon: "ai-alert-triangle",
                });
            }
            this.pickedLocation = didSearch;
        }
    }
    /**
     * When a result is filtered in location-viewer.
     */
    onResultFiltered($event) {
        this.filteredResult.emit($event);
    }
    /**
     * Implements keyboard and mouse commands
     */
    onKeyCommand(event) {
        /* Disable accidental submit when enter key is pressed */
        if (event.key === "Enter") {
            event.preventDefault();
        }
        /* zoom in/out using ctrl + scroll to zoom in or out. Show notification if only scroll is used. */
        if (event.type === "wheel" && this.cursorOnLeaflet) {
            if (event.shiftKey) {
                const direction = event.deltaY > 0 ? "out" : "in";
                this.renderer.addClass(document.body, "is-map-interaction");
                if (direction === "out") {
                    this.zoomOut();
                }
                else {
                    this.zoomIn();
                }
            }
            else {
                this.renderer.removeClass(document.body, "is-map-interaction");
                this.setNotification({
                    status: "default",
                    text: this.zoomInfoNotification,
                    icon: "ai-alert-circle",
                });
            }
        }
        else {
            this.renderer.removeClass(document.body, "is-map-interaction");
        }
        /* Close flyout when escape key is pressed */
        if (event.key === "Escape" && this.didSearch) {
            this.didSearch = false;
        }
        /* Cancel location search by click when escape key is pressed. */
        if (event.key === "Escape") {
            this.cancelPickingEvents();
            this.pickLocationActive = false;
            this.pickedLocation = false;
        }
        /* When pressing enter, select first value in found locations list. */
        if (event.key === "Enter" && this.didSearch) {
            if (this.hasResults) {
                this.onLocationSelect(null, this.foundLocations[this.highlightedLocationResult]);
            }
            else {
                this.onLocationSelect(null, this.selectedLocation);
            }
            this.pickedLocation = false;
        }
        if (this.hasResults && this.didSearch) {
            /* When using arrow keys, select next/previous result in found locations list. */
            if (event.key === "ArrowUp") {
                if (this.highlightedLocationResult > 0) {
                    this.highlightedLocationResult--;
                }
            }
            if (event.key === "ArrowDown") {
                if (this.highlightedLocationResult < this.foundLocations.length - 1) {
                    this.highlightedLocationResult++;
                }
            }
        }
    }
    /**
     * Determines whether the cursor is hovering over the leaflet instance or not.
     */
    isCursorOnLeaflet(cursorOnLeaflet) {
        this.cursorOnLeaflet = cursorOnLeaflet;
    }
    /**
     * Close the notification manually
     */
    closeNotification() {
        this.leafletNotification = null;
    }
    /**
     * Clear watch user position
     */
    clearWatch() {
        if (this.geoLocateId && navigator && navigator.geolocation) {
            navigator.geolocation.clearWatch(this.geoLocateId);
            this.geoLocateId = null;
        }
        this.removeProximityCircle();
        if (this.clearWatchTimeoutId != null) {
            clearTimeout(this.clearWatchTimeoutId);
            this.clearWatchTimeoutId = null;
        }
    }
    /**
     * Init leaflet map with default values and register feature layers if provided.
     */
    initLocationPicker() {
        this.leafletMap = new LocationViewerMap({
            zoom: this.defaultZoom,
            center: this.mapCenter,
            onAddPolygon: (layer) => {
                this.addPolygon.emit(layer);
            },
            onAddLine: (layer) => {
                this.addLine.emit(layer);
            },
            onEditFeature: (feature) => {
                this.editFeature.emit(feature);
            },
        }, this.locationViewerService);
        this.leafletMap.onInit.subscribe(() => {
            this.mapLoaded = true;
            if (this.selectedLocation && this.selectedLocation.position) {
                this.selectedLocation = this.selectedLocation;
            }
            else if (this.locateUserOnInit) {
                /* Get users location on load only when no selectedLocation was set. */
                this.getDeviceLocation();
            }
            this.registerFeatureLayers();
        });
    }
    /**
     * Triggers a search with latest position of device
     */
    searchWithCachedPosition() {
        if (this.cachedPosition && this.cachedPosition.coords) {
            this.setLocationDynamically(this.cachedPosition.coords.latitude, this.cachedPosition.coords.longitude, true);
            this.isLocating = false;
        }
    }
    /**
     * Triggers a search when selectedLocation was updated from outside our component.
     */
    setInitialLocation(initialLocation) {
        this.cancelGeolocation();
        if (!("options" in initialLocation) ||
            !("triggerSearch" in initialLocation.options) ||
            initialLocation.options.triggerSearch) {
            this.onSearch(`${initialLocation.position.lat},${initialLocation.position.lng}`, initialLocation.label &&
                this.locationPickerHelper.isCoordinate(initialLocation.label));
        }
        else {
            this.addMapMarker([
                initialLocation.position.lat,
                initialLocation.position.lng,
            ]);
            this.setView([
                initialLocation.position.lat,
                initialLocation.position.lng,
            ]);
        }
    }
    /**
     * Capture coordinates from clicking the map and run a search.
     */
    registerMapClick($event) {
        this.removeGeometry();
        this.cancelPickingEvents();
        this.pickLocationActive = false;
        this.pickedLocation = true;
        if ($event.latlng) {
            this.setLocationDynamically($event.latlng.lat, $event.latlng.lng);
        }
    }
    /**
     * Sets a dynamically fetched location when using locate-me or pick location on map
     */
    setLocationDynamically(lat, lng, setView = false) {
        this.resetFoundLocations();
        this.onSearch(`${lat.toFixed(6)},${lng.toFixed(6)}`);
        if (setView) {
            this.setView([lat.toFixed(6), lng.toFixed(6)]);
        }
    }
    /**
     * Sets leaflet map view to selected coords. With preferred zoomlevel.
     */
    setView(coords) {
        if (this.onSelectZoom) {
            this.leafletMap.setView(coords, this.onSelectZoom);
        }
        else {
            this.leafletMap.setView(coords, this.leafletMap.map.getZoom());
        }
    }
    /**
     * Registers optional feature layers and adds markers to the leaflet instance.
     */
    registerFeatureLayers() {
        if (this.featureLayers.length > 0) {
            this.featureLayers.map((featureLayer) => {
                this.leafletMap.addFeatureLayer({
                    url: featureLayer.url,
                    pointToLayer: (geojson, latlng) => {
                        return this.leafletMap.addHtmlMarker(latlng, this.createMarker(featureLayer.icon && featureLayer.icon.color
                            ? featureLayer.icon.color
                            : undefined, featureLayer.icon && featureLayer.icon.iconClass
                            ? featureLayer.icon.iconClass
                            : undefined, featureLayer.icon && featureLayer.icon.size
                            ? featureLayer.icon.size
                            : undefined));
                    },
                });
            });
        }
    }
    /**
     * Adds a marker on a given coordinate and zooms in on this location.
     *
     * @param coords array containing lat & lng
     * @param location the selected location
     * @param keepGeometry whether or not to remove existing geometry
     * @param keepMarker whether or not to remove existing marker
     * @param marker the marker styling itself
     */
    addMapMarker(coords, location = null, keepGeometry = false, keepMarker = false, marker = null) {
        if (!keepMarker) {
            this.removeMarker();
        }
        if (!keepGeometry) {
            this.removeGeometry();
        }
        if (marker === null) {
            marker = this.createMarker();
        }
        this.selectedLocationMarker = this.leafletMap.addHtmlMarker(coords, marker);
        this.selectedLocationMarker.dragging.enable();
        this.selectedLocationMarker.on("dragend", (_) => {
            const newCoords = this.selectedLocationMarker.getLatLng();
            const searchValue = newCoords
                ? `${newCoords.lat.toFixed(6)},${newCoords.lng.toFixed(6)}`
                : "";
            this.pickedLocation = true;
            this.resetFoundLocations();
            this.onSearch(searchValue);
        });
        if (location) {
            this.writeValue(location);
        }
    }
    /* Adds a marker on a given coordinate and zooms in on this location. */
    addResultMarker(coords, pointDetails) {
        this.removeGeometry();
        this.calculatedLocationMarker = this.leafletMap.addHtmlMarker(coords, this.createMarker("var(--THEME1-600)", "ai-controls-record", "var(--SPACER)", {
            top: "-0.4rem",
            left: "-0.4rem",
        }, pointDetails));
        this.setView(coords);
    }
    /**
     * Adds proximity circle to show the accuracy of received coordinates
     */
    showProximityCircle(coords, accuracy) {
        let zoomLevel = 15;
        this.removeProximityCircle();
        this.proximityCircle = this.locationViewerService.L.circle(coords, accuracy, {
            opacity: 1,
            color: "#FFFFFF",
            fillColor: "#3388ff",
            className: "proximity",
        });
        this.proximityCenter = this.locationViewerService.L.circle(coords, 15, {
            fillOpacity: 1,
            color: "#FFFFFF",
            fillColor: "#000000",
            className: "proximity-center",
        });
        this.proximityCircle.addTo(this.leafletMap.map);
        this.proximityCenter.addTo(this.leafletMap.map);
        const boundZoom = this.leafletMap.map.getBoundsZoom(this.proximityCircle.getBounds());
        if (boundZoom < zoomLevel) {
            zoomLevel = boundZoom;
        }
        this.leafletMap.setView(coords, zoomLevel);
    }
    /**
     * Removes the proximity circle from the map
     */
    removeProximityCircle() {
        if (this.proximityCircle) {
            this.proximityCircle.remove();
            this.proximityCircle = null;
        }
        if (this.proximityCenter) {
            this.proximityCenter.remove();
            this.proximityCenter = null;
        }
    }
    /**
     * Defines the custom marker markup.
     */
    createMarker(color = "var(--THEME1-600)", icon = "ai-pin", size = "var(--SPACER)", position = {
        top: "-0.75rem",
        left: "-0.6rem",
    }, pointDetails) {
        const markerStyle = `color: ${color}; font-size: ${size}; top: ${position.top}; left: ${position.left}`;
        const markerIcon = `<svg aria-hidden="true"><use href="#${icon}" style="fill: ${pointDetails?.color}; fill-opacity: ${pointDetails?.opacity}%; stroke: ${pointDetails?.strokeColor}; stroke-width: ${pointDetails?.strokeWidth}; stroke-opacity: 1;" /></svg>`;
        return `<span style="${markerStyle}" class="ai ngx-location-picker-marker">${markerIcon}</span>`;
    }
    createPinMarker() {
        return this.createMarker("var(--THEME1-600)", "ai-pin", "2.5rem", {
            top: "-1.75rem",
            left: "-0.75rem",
        });
    }
    /**
     * Removes specific marker from leaflet instance.
     */
    removeMarker(calculatedOnly = false) {
        if (this.selectedLocationMarker && !calculatedOnly) {
            this.leafletMap.removeLayer(this.selectedLocationMarker);
        }
        if (this.calculatedLocationMarker) {
            this.leafletMap.removeLayer(this.calculatedLocationMarker);
        }
    }
    /**
     * Add found geo shape to leaflet and determine center coordinates
     */
    addMapGeoJson(label, geometryShape, geometry) {
        this.removeGeometry();
        const geoJson = {
            type: "Feature",
            properties: {
                name: label,
            },
            geometry: {
                type: geometryShape,
                coordinates: geometryShape === "MultiPolygon" ? [geometry] : geometry,
            },
        };
        try {
            this.selectedLocationGeometry = this.leafletMap.addGeoJSON(geoJson, {});
        }
        catch (error) {
            console.log(error);
            // when addGeoJson throw an error ==> remove loading icon
            this.searching = false;
        }
        const bounds = this.selectedLocationGeometry.getBounds();
        const shapeCenter = this.selectedLocationGeometry.getBounds().getCenter();
        if (this.selectedLocation && shapeCenter) {
            if (!this.pickedLocation) {
                this.setView(shapeCenter);
                if (this.changeZoomLevelOnLocationSelect) {
                    this.leafletMap.map.fitBounds(bounds);
                }
            }
            else {
                // only change map zoomlevel if the selection is not the default selection after location was picked
                if (this.changeZoomLevelOnLocationSelect && !this.didSearch) {
                    this.leafletMap.map.fitBounds(bounds);
                }
            }
            if (this.selectedLocation.position) {
                this.selectedLocation.position.wgs84 = shapeCenter;
            }
            if (this.selectedLocation.location &&
                this.selectedLocation.location.position) {
                this.selectedLocation.location.position.wgs84 = shapeCenter;
            }
        }
    }
    /**
     * Resets found locations to empty array
     */
    resetFoundLocations() {
        this.foundLocations = [];
    }
    /**
     * Resets properties related to location search
     */
    resetLocationSearchFields() {
        this.didSearch = false;
        this.searching = false;
        this.pickedLocation = false;
        this.previousLocation = null;
        this.resetFoundLocations();
    }
    /**
     * Removes added geometry area from leaflet instance.
     */
    removeGeometry() {
        if (this.selectedLocationGeometry) {
            this.leafletMap.removeLayer(this.selectedLocationGeometry);
        }
    }
    /**
     * Cancels geolocation if currently running
     */
    cancelGeolocation() {
        this.isLocating = false;
        if (this.geoLocate && this.geoLocateId) {
            this.geoLocate.clearWatch(this.geoLocateId);
        }
    }
    /**
     * Removes and adds the expected events after cancelling picking
     */
    cancelPickingEvents() {
        this.leafletMap.map.removeEventListener("click");
        this.locationViewer.registerOperationalLayerClickEvent();
    }
    /**
     * Show a notification on the leaflet map.
     */
    setNotification(notification) {
        this.leafletNotification = notification;
    }
    /**
     * Does the input check on to see if given input equals to the current selected street name
     */
    inputStringEqualsSelectedStreetName(input, expectedStreetName) {
        return input?.trim()?.toLocaleLowerCase().startsWith(expectedStreetName?.trim()?.toLocaleLowerCase());
    }
}
/** @nocollapse */ NgxLocationPickerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: NgxLocationPickerComponent, deps: [{ token: NgxLocationPickerService }, { token: NgxLocationPickerHelper }, { token: i3.LocationViewerMapService }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component });
/** @nocollapse */ NgxLocationPickerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: NgxLocationPickerComponent, selector: "aui-location-picker", inputs: { baseUrl: "baseUrl", defaultZoom: "defaultZoom", onSelectZoom: "onSelectZoom", changeZoomLevelOnLocationSelect: "changeZoomLevelOnLocationSelect", mapCenter: "mapCenter", hasSidebar: "hasSidebar", showMap: "showMap", showClearInputButton: "showClearInputButton", featureLayers: "featureLayers", placeholder: "placeholder", noResultsLabel: "noResultsLabel", defaultOptionLabel: "defaultOptionLabel", clearInputAriaLabel: "clearInputAriaLabel", locationPickAriaLabel: "locationPickAriaLabel", zoomInAriaLabel: "zoomInAriaLabel", zoomOutAriaLabel: "zoomOutAriaLabel", textInputAriaLabel: "textInputAriaLabel", locateMeAriaLabel: "locateMeAriaLabel", locatingAriaLabel: "locatingAriaLabel", locateMeNotSupportedNotification: "locateMeNotSupportedNotification", locateMeNotAllowedNotification: "locateMeNotAllowedNotification", locateMeUnavailableNotification: "locateMeUnavailableNotification", locateMeTimeoutNotification: "locateMeTimeoutNotification", locateMeUnknownNotification: "locateMeUnknownNotification", coordinateErrorNotification: "coordinateErrorNotification", zoomInfoNotification: "zoomInfoNotification", defaultTileLayerLabel: "defaultTileLayerLabel", tileLayer: "tileLayer", tileLayerIsVectorBased: "tileLayerIsVectorBased", minInputLength: "minInputLength", locationsLimit: "locationsLimit", locationLayers: "locationLayers", prioritizeLayers: "prioritizeLayers", sortBy: "sortBy", onlyAntwerp: "onlyAntwerp", countryCodes: "countryCodes", bufferSearch: "bufferSearch", coordinateSearch: "coordinateSearch", locateUserOnInit: "locateUserOnInit", debounceTime: "debounceTime", cascadingCoordinateReturnSingle: "cascadingCoordinateReturnSingle", cascadingCoordinateLimit: "cascadingCoordinateLimit", cascadingCoordinateRules: "cascadingCoordinateRules", cascadingCoordinateGuid: "cascadingCoordinateGuid", geoApiBaseUrl: "geoApiBaseUrl", showLayerManagement: "showLayerManagement", showSelectionTools: "showSelectionTools", showMeasureTools: "showMeasureTools", showWhatIsHereButton: "showWhatIsHereButton", supportingLayerOptions: "supportingLayerOptions", operationalLayerOptions: "operationalLayerOptions", filterLayers: "filterLayers", addCoordinateToResultsAt: "addCoordinateToResultsAt", locationKeywords: "locationKeywords", searchStreetNameForAddress: "searchStreetNameForAddress", positionOptions: "positionOptions", trackPosition: "trackPosition" }, outputs: { addPolygon: "addPolygon", addLine: "addLine", editFeature: "editFeature", locationSelect: "locationSelect", filteredResult: "filteredResult" }, host: { listeners: { "window:wheel": "onKeyCommand($event)", "window:keydown": "onKeyCommand($event)" } }, providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef((() => NgxLocationPickerComponent)),
            multi: true,
        },
    ], viewQueries: [{ propertyName: "locationViewer", first: true, predicate: NgxLocationViewerComponent, descendants: true }, { propertyName: "leafletSearchField", first: true, predicate: ["leafletSearch"], descendants: true }], ngImport: i0, template: "<div class=\"a-input\" [class.has-map]=\"showMap\">\n  <div class=\"a-input__search\" [class.has-sidebar]=\"hasSidebar\">\n    <div class=\"a-input__wrapper has-inline-addon\">\n      <input #leafletSearch id=\"leaflet-search\" type=\"text\" name=\"leaflet-search\" [placeholder]=\"placeholder\"\n        [attr.aria-label]=\"textInputAriaLabel\" [(ngModel)]=\"selectedLocationLabel\"\n        (ngModelChange)=\"onInputChange($event)\" autocomplete=\"off\" (blur)=\"setDidSearch()\" />\n      <div class=\"inline-addon\" *ngIf=\"showClearInputButton\">\n        <div *ngIf=\"searching\" class=\"a-spinner\" role=\"alert\">\n          <span class=\"a-spinner__circle\">\n            <span class=\"u-screen-reader-only\">...</span>\n          </span>\n        </div>\n        <button *ngIf=\"!inputHasValue && !searching\" class=\"a-button a-button--s a-button--text has-icon\" type=\"button\"\n          (click)=\"emptyField()\" [attr.aria-label]=\"clearInputAriaLabel\">\n          <aui-icon name=\"ai-close\"></aui-icon>\n        </button>\n      </div>\n    </div>\n\n    <div class=\"m-flyout m-flyout--full\" [class.is-open]=\"didSearch && !searching\">\n      <div class=\"m-flyout__content\">\n        <p *ngIf=\"!hasResults && !searching; else results\" class=\"u-margin-s\">{{ noResultsLabel }}</p>\n        <ng-template #results>\n          <ul class=\"a-list a-list--lined a-list--flushed a-list__results\">\n            <li *ngFor=\"let location of foundLocations; let ii = index\" class=\"a-list__item\">\n              <a href=\"#\" [class]=\"{\n                'a-list__content': true,\n                'is-active': ii === highlightedLocationResult,\n              }\" (click)=\"onLocationSelect($event, location)\">\n                <p [innerHTML]=\"location.label | highlight: selectedLocation?.label\"></p>\n                <small>{{ location.layer }}</small>\n              </a>\n            </li>\n          </ul>\n        </ng-template>\n        <div *ngIf=\"!hasResults && pickedLocation && !searching\" (click)=\"onLocationSelect($event, selectedLocation)\"\n          class=\"use-coordinate\" [class.is-highlighted]=\"!hasResults && pickedLocation\">\n          <p>{{ defaultOptionLabel }}</p>\n          <small>{{ selectedLocation.label }}</small>\n        </div>\n      </div>\n    </div>\n    <div *ngIf=\"leafletNotification?.text\">\n      <div role=\"alertdialog\" aria-live=\"assertive\"\n        class=\"m-location-picker__notification-panel u-bg-white m-alert m-alert--inline m-alert--{{ leafletNotification.status }}\">\n        <p><aui-icon [name]=\"leafletNotification.icon\" class=\"u-margin-right-xxs\"></aui-icon> {{\n          leafletNotification.text }}</p>\n        <button class=\"a-button a-button--text a-button--{{ leafletNotification.status }} has-icon m-alert__close\"\n          aria-label=\"Close\" (click)=\"closeNotification()\">\n          <aui-icon name=\"ai-close\"></aui-icon>\n        </button>\n      </div>\n    </div>\n  </div>\n<aui-location-viewer *ngIf=\"showMap\"\n  [leafletMap]=\"leafletMap\"\n  [(hasSidebar)]=\"hasSidebar\"\n  [geoApiBaseUrl]=\"geoApiBaseUrl\"\n  [showLayerManagement]=\"showLayerManagement\"\n  [showSelectionTools]=\"showSelectionTools\"\n  [showMeasureTools]=\"showMeasureTools\"\n  [showWhatIsHereButton]=\"showWhatIsHereButton\"\n  [supportingLayerOptions]=\"supportingLayerOptions\"\n  [operationalLayerOptions]=\"operationalLayerOptions\"\n  [filterLayers]=\"filterLayers\" [tileLayer]=\"tileLayer\"\n  [tileLayerIsVectorBased]=\"tileLayerIsVectorBased\"\n  [defaultTileLayerLabel]=\"defaultTileLayerLabel\"\n  [class.is-picking]=\"pickLocationActive\"\n  (mouseover)=\"isCursorOnLeaflet(true)\"\n  (mouseout)=\"isCursorOnLeaflet(false)\"\n  (filteredResult)=\"onResultFiltered($event)\">\n    <div controls bottom left>\n      <button type=\"button\" class=\"a-button has-icon u-margin-bottom-xs button-location-picking\"\n        (click)=\"pickLocationOnMap()\" [class.a-button--outlined]=\"pickLocationActive\"\n        [attr.aria-label]=\"locationPickAriaLabel\">\n        <aui-icon name=\"ai-pin\"></aui-icon>\n      </button>\n    </div>\n    <div controls bottom right>\n        <button type=\"button\" class=\"a-button has-icon\" [attr.aria-label]=\"locateMeAriaLabel\"\n                [class.a-button--outlined]=\"isLocating\"\n                (click)=\"getDeviceLocation()\">\n            <aui-icon *ngIf=\"!isLocating\" name=\"ai-compass-arrow\"></aui-icon>\n            <div *ngIf=\"isLocating\" class=\"a-spinner\" role=\"alert\">\n              <span class=\"a-spinner__circle\">\n                <span class=\"u-screen-reader-only\">{{ locatingAriaLabel }}</span>\n              </span>\n            </div>\n        </button>\n    </div>\n    <div *ngIf=\"hasSidebar\">\n      <ng-content></ng-content>\n    </div>\n  </aui-location-viewer>\n</div>\n", styles: ["::ng-deep body.is-map-interaction{overflow:hidden}::ng-deep .ngx-location-picker-marker{position:relative}::ng-deep .ngx-location-picker-marker svg{filter:drop-shadow(0 0 2px var(--TEXT-COLOR-INVERTED))}::ng-deep .is-picking .leaflet-grab,::ng-deep .is-picking .leaflet-interactive{cursor:url(\"data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='32' height='32' viewBox='0 0 24 24'%3E%3Cg stroke-linecap='round' stroke-width='6.25%%25' stroke='%230057b7' fill='none' stroke-linejoin='round'%3E%3Cpath d='M12 .71c4.14 0 7.5 3.35 7.5 7.49 0 3.54-5.5 12.38-7.08 14.85-.15.23-.46.3-.7.15-.07-.04-.12-.1-.16-.16C9.58 20.68 4.08 11.84 4.08 8.2 4.08 4.86 7.35.71 12 .71z'/%3E%3Cpath d='M12 5.21a3 3 0 1 0 0 6 3 3 0 0 0 0-6z'/%3E%3C/g%3E%3C/svg%3E\") 16 26,pointer}::ng-deep .controls-top-left{margin-top:3.75rem}::ng-deep .proximity{animation:svg-border-pulse 2s ease-out infinite;filter:drop-shadow(0px 0px 6px rgba(0,0,0,.2))}::ng-deep .proximity-center{animation:pulsate 2s ease-out infinite;opacity:0}.a-button.a-button--outlined.button-location-picking{--btn-bg-color: var(--THEME1-100)}.a-input__wrapper.has-inline-addon{position:relative;z-index:10}.a-input__wrapper input{padding-right:4.5rem}.a-input__wrapper .inline-addon{position:absolute;right:calc(var(--SPACER) / 4);top:calc(var(--SPACER) / 4)}.a-input__wrapper .inline-addon .a-spinner{margin-right:calc(var(--SPACER) / 12);margin-top:calc(var(--SPACER) / 12)}.a-input__search{left:var(--SPACER-S);position:absolute;top:var(--SPACER-S);width:calc(100% - var(--SPACER-S) * 2)}.a-input__search.has-sidebar{width:calc(100% - var(--SPACER-S) * 2 - 300px);right:var(--SPACER-S);left:auto}.m-location-picker__notification-panel{margin-top:var(--SPACER-XS);z-index:10;width:100%}.m-location-picker__notification-panel.m-alert{min-height:calc(var(--SPACER-XL) + 2px)}.m-flyout{display:block}.m-flyout__content{box-shadow:none;margin-top:-1px;max-height:32.25rem;overflow:hidden;overflow-y:auto;width:100%}.m-flyout__content .use-coordinate{padding:1.125rem 0 1.125rem .75rem;margin:0}.m-flyout__content .use-coordinate{cursor:pointer;transition:all var(--ANIMATION-NORMAL);border-top:var(--BORDER-WIDTH) solid var(--BORDER-COLOR)}.m-flyout__content .use-coordinate:hover,.m-flyout__content .use-coordinate.is-highlighted{background:#f3f3f3}.m-flyout__content .use-coordinate small{margin:.375rem 0 0}.m-flyout__content .a-list__results .a-list__content{flex-direction:column}.m-flyout__content .a-list__results p:first-letter{text-transform:uppercase}@keyframes pulsate{0%,to{opacity:.2}50%{opacity:1}}@keyframes svg-border-pulse{0%,to{stroke-width:4px}50%{stroke-width:2px}}\n"], dependencies: [{ kind: "directive", type: i4.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i4.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i4.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i5.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i6.IconComponent, selector: "aui-icon", inputs: ["name", "ariaLabel", "className"] }, { kind: "component", type: i3.NgxLocationViewerComponent, selector: "aui-location-viewer", inputs: ["geoApiBaseUrl", "defaultZoom", "mapCenter", "hasSidebar", "showSidebar", "showLayerManagement", "showSelectionTools", "showMeasureTools", "showWhatIsHereButton", "supportingLayerOptions", "operationalLayerOptions", "filterLayers", "leafletMap", "defaultTileLayerLabel", "tileLayer", "tileLayerIsVectorBased", "zoomOnMarkerSelect", "translations", "currentPosition"], outputs: ["hasSidebarChange", "addPolygon", "addLine", "editFeature", "filteredResult", "markerClicked", "whatIsHereSelected"] }, { kind: "pipe", type: HighlightSearchDirective, name: "highlight" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: NgxLocationPickerComponent, decorators: [{
            type: Component,
            args: [{ selector: "aui-location-picker", providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef((() => NgxLocationPickerComponent)),
                            multi: true,
                        },
                    ], template: "<div class=\"a-input\" [class.has-map]=\"showMap\">\n  <div class=\"a-input__search\" [class.has-sidebar]=\"hasSidebar\">\n    <div class=\"a-input__wrapper has-inline-addon\">\n      <input #leafletSearch id=\"leaflet-search\" type=\"text\" name=\"leaflet-search\" [placeholder]=\"placeholder\"\n        [attr.aria-label]=\"textInputAriaLabel\" [(ngModel)]=\"selectedLocationLabel\"\n        (ngModelChange)=\"onInputChange($event)\" autocomplete=\"off\" (blur)=\"setDidSearch()\" />\n      <div class=\"inline-addon\" *ngIf=\"showClearInputButton\">\n        <div *ngIf=\"searching\" class=\"a-spinner\" role=\"alert\">\n          <span class=\"a-spinner__circle\">\n            <span class=\"u-screen-reader-only\">...</span>\n          </span>\n        </div>\n        <button *ngIf=\"!inputHasValue && !searching\" class=\"a-button a-button--s a-button--text has-icon\" type=\"button\"\n          (click)=\"emptyField()\" [attr.aria-label]=\"clearInputAriaLabel\">\n          <aui-icon name=\"ai-close\"></aui-icon>\n        </button>\n      </div>\n    </div>\n\n    <div class=\"m-flyout m-flyout--full\" [class.is-open]=\"didSearch && !searching\">\n      <div class=\"m-flyout__content\">\n        <p *ngIf=\"!hasResults && !searching; else results\" class=\"u-margin-s\">{{ noResultsLabel }}</p>\n        <ng-template #results>\n          <ul class=\"a-list a-list--lined a-list--flushed a-list__results\">\n            <li *ngFor=\"let location of foundLocations; let ii = index\" class=\"a-list__item\">\n              <a href=\"#\" [class]=\"{\n                'a-list__content': true,\n                'is-active': ii === highlightedLocationResult,\n              }\" (click)=\"onLocationSelect($event, location)\">\n                <p [innerHTML]=\"location.label | highlight: selectedLocation?.label\"></p>\n                <small>{{ location.layer }}</small>\n              </a>\n            </li>\n          </ul>\n        </ng-template>\n        <div *ngIf=\"!hasResults && pickedLocation && !searching\" (click)=\"onLocationSelect($event, selectedLocation)\"\n          class=\"use-coordinate\" [class.is-highlighted]=\"!hasResults && pickedLocation\">\n          <p>{{ defaultOptionLabel }}</p>\n          <small>{{ selectedLocation.label }}</small>\n        </div>\n      </div>\n    </div>\n    <div *ngIf=\"leafletNotification?.text\">\n      <div role=\"alertdialog\" aria-live=\"assertive\"\n        class=\"m-location-picker__notification-panel u-bg-white m-alert m-alert--inline m-alert--{{ leafletNotification.status }}\">\n        <p><aui-icon [name]=\"leafletNotification.icon\" class=\"u-margin-right-xxs\"></aui-icon> {{\n          leafletNotification.text }}</p>\n        <button class=\"a-button a-button--text a-button--{{ leafletNotification.status }} has-icon m-alert__close\"\n          aria-label=\"Close\" (click)=\"closeNotification()\">\n          <aui-icon name=\"ai-close\"></aui-icon>\n        </button>\n      </div>\n    </div>\n  </div>\n<aui-location-viewer *ngIf=\"showMap\"\n  [leafletMap]=\"leafletMap\"\n  [(hasSidebar)]=\"hasSidebar\"\n  [geoApiBaseUrl]=\"geoApiBaseUrl\"\n  [showLayerManagement]=\"showLayerManagement\"\n  [showSelectionTools]=\"showSelectionTools\"\n  [showMeasureTools]=\"showMeasureTools\"\n  [showWhatIsHereButton]=\"showWhatIsHereButton\"\n  [supportingLayerOptions]=\"supportingLayerOptions\"\n  [operationalLayerOptions]=\"operationalLayerOptions\"\n  [filterLayers]=\"filterLayers\" [tileLayer]=\"tileLayer\"\n  [tileLayerIsVectorBased]=\"tileLayerIsVectorBased\"\n  [defaultTileLayerLabel]=\"defaultTileLayerLabel\"\n  [class.is-picking]=\"pickLocationActive\"\n  (mouseover)=\"isCursorOnLeaflet(true)\"\n  (mouseout)=\"isCursorOnLeaflet(false)\"\n  (filteredResult)=\"onResultFiltered($event)\">\n    <div controls bottom left>\n      <button type=\"button\" class=\"a-button has-icon u-margin-bottom-xs button-location-picking\"\n        (click)=\"pickLocationOnMap()\" [class.a-button--outlined]=\"pickLocationActive\"\n        [attr.aria-label]=\"locationPickAriaLabel\">\n        <aui-icon name=\"ai-pin\"></aui-icon>\n      </button>\n    </div>\n    <div controls bottom right>\n        <button type=\"button\" class=\"a-button has-icon\" [attr.aria-label]=\"locateMeAriaLabel\"\n                [class.a-button--outlined]=\"isLocating\"\n                (click)=\"getDeviceLocation()\">\n            <aui-icon *ngIf=\"!isLocating\" name=\"ai-compass-arrow\"></aui-icon>\n            <div *ngIf=\"isLocating\" class=\"a-spinner\" role=\"alert\">\n              <span class=\"a-spinner__circle\">\n                <span class=\"u-screen-reader-only\">{{ locatingAriaLabel }}</span>\n              </span>\n            </div>\n        </button>\n    </div>\n    <div *ngIf=\"hasSidebar\">\n      <ng-content></ng-content>\n    </div>\n  </aui-location-viewer>\n</div>\n", styles: ["::ng-deep body.is-map-interaction{overflow:hidden}::ng-deep .ngx-location-picker-marker{position:relative}::ng-deep .ngx-location-picker-marker svg{filter:drop-shadow(0 0 2px var(--TEXT-COLOR-INVERTED))}::ng-deep .is-picking .leaflet-grab,::ng-deep .is-picking .leaflet-interactive{cursor:url(\"data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='32' height='32' viewBox='0 0 24 24'%3E%3Cg stroke-linecap='round' stroke-width='6.25%%25' stroke='%230057b7' fill='none' stroke-linejoin='round'%3E%3Cpath d='M12 .71c4.14 0 7.5 3.35 7.5 7.49 0 3.54-5.5 12.38-7.08 14.85-.15.23-.46.3-.7.15-.07-.04-.12-.1-.16-.16C9.58 20.68 4.08 11.84 4.08 8.2 4.08 4.86 7.35.71 12 .71z'/%3E%3Cpath d='M12 5.21a3 3 0 1 0 0 6 3 3 0 0 0 0-6z'/%3E%3C/g%3E%3C/svg%3E\") 16 26,pointer}::ng-deep .controls-top-left{margin-top:3.75rem}::ng-deep .proximity{animation:svg-border-pulse 2s ease-out infinite;filter:drop-shadow(0px 0px 6px rgba(0,0,0,.2))}::ng-deep .proximity-center{animation:pulsate 2s ease-out infinite;opacity:0}.a-button.a-button--outlined.button-location-picking{--btn-bg-color: var(--THEME1-100)}.a-input__wrapper.has-inline-addon{position:relative;z-index:10}.a-input__wrapper input{padding-right:4.5rem}.a-input__wrapper .inline-addon{position:absolute;right:calc(var(--SPACER) / 4);top:calc(var(--SPACER) / 4)}.a-input__wrapper .inline-addon .a-spinner{margin-right:calc(var(--SPACER) / 12);margin-top:calc(var(--SPACER) / 12)}.a-input__search{left:var(--SPACER-S);position:absolute;top:var(--SPACER-S);width:calc(100% - var(--SPACER-S) * 2)}.a-input__search.has-sidebar{width:calc(100% - var(--SPACER-S) * 2 - 300px);right:var(--SPACER-S);left:auto}.m-location-picker__notification-panel{margin-top:var(--SPACER-XS);z-index:10;width:100%}.m-location-picker__notification-panel.m-alert{min-height:calc(var(--SPACER-XL) + 2px)}.m-flyout{display:block}.m-flyout__content{box-shadow:none;margin-top:-1px;max-height:32.25rem;overflow:hidden;overflow-y:auto;width:100%}.m-flyout__content .use-coordinate{padding:1.125rem 0 1.125rem .75rem;margin:0}.m-flyout__content .use-coordinate{cursor:pointer;transition:all var(--ANIMATION-NORMAL);border-top:var(--BORDER-WIDTH) solid var(--BORDER-COLOR)}.m-flyout__content .use-coordinate:hover,.m-flyout__content .use-coordinate.is-highlighted{background:#f3f3f3}.m-flyout__content .use-coordinate small{margin:.375rem 0 0}.m-flyout__content .a-list__results .a-list__content{flex-direction:column}.m-flyout__content .a-list__results p:first-letter{text-transform:uppercase}@keyframes pulsate{0%,to{opacity:.2}50%{opacity:1}}@keyframes svg-border-pulse{0%,to{stroke-width:4px}50%{stroke-width:2px}}\n"] }]
        }], ctorParameters: function () { return [{ type: NgxLocationPickerService }, { type: NgxLocationPickerHelper }, { type: i3.LocationViewerMapService }, { type: i0.Renderer2 }]; }, propDecorators: { baseUrl: [{
                type: Input
            }], defaultZoom: [{
                type: Input
            }], onSelectZoom: [{
                type: Input
            }], changeZoomLevelOnLocationSelect: [{
                type: Input
            }], mapCenter: [{
                type: Input
            }], hasSidebar: [{
                type: Input
            }], showMap: [{
                type: Input
            }], showClearInputButton: [{
                type: Input
            }], featureLayers: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], noResultsLabel: [{
                type: Input
            }], defaultOptionLabel: [{
                type: Input
            }], clearInputAriaLabel: [{
                type: Input
            }], locationPickAriaLabel: [{
                type: Input
            }], zoomInAriaLabel: [{
                type: Input
            }], zoomOutAriaLabel: [{
                type: Input
            }], textInputAriaLabel: [{
                type: Input
            }], locateMeAriaLabel: [{
                type: Input
            }], locatingAriaLabel: [{
                type: Input
            }], locateMeNotSupportedNotification: [{
                type: Input
            }], locateMeNotAllowedNotification: [{
                type: Input
            }], locateMeUnavailableNotification: [{
                type: Input
            }], locateMeTimeoutNotification: [{
                type: Input
            }], locateMeUnknownNotification: [{
                type: Input
            }], coordinateErrorNotification: [{
                type: Input
            }], zoomInfoNotification: [{
                type: Input
            }], defaultTileLayerLabel: [{
                type: Input
            }], tileLayer: [{
                type: Input
            }], tileLayerIsVectorBased: [{
                type: Input
            }], minInputLength: [{
                type: Input
            }], locationsLimit: [{
                type: Input
            }], locationLayers: [{
                type: Input
            }], prioritizeLayers: [{
                type: Input
            }], sortBy: [{
                type: Input
            }], onlyAntwerp: [{
                type: Input
            }], countryCodes: [{
                type: Input
            }], bufferSearch: [{
                type: Input
            }], coordinateSearch: [{
                type: Input
            }], locateUserOnInit: [{
                type: Input
            }], debounceTime: [{
                type: Input
            }], cascadingCoordinateReturnSingle: [{
                type: Input
            }], cascadingCoordinateLimit: [{
                type: Input
            }], cascadingCoordinateRules: [{
                type: Input
            }], cascadingCoordinateGuid: [{
                type: Input
            }], geoApiBaseUrl: [{
                type: Input
            }], showLayerManagement: [{
                type: Input
            }], showSelectionTools: [{
                type: Input
            }], showMeasureTools: [{
                type: Input
            }], showWhatIsHereButton: [{
                type: Input
            }], supportingLayerOptions: [{
                type: Input
            }], operationalLayerOptions: [{
                type: Input
            }], filterLayers: [{
                type: Input
            }], addCoordinateToResultsAt: [{
                type: Input
            }], locationKeywords: [{
                type: Input
            }], searchStreetNameForAddress: [{
                type: Input
            }], positionOptions: [{
                type: Input
            }], trackPosition: [{
                type: Input
            }], addPolygon: [{
                type: Output
            }], addLine: [{
                type: Output
            }], editFeature: [{
                type: Output
            }], locationSelect: [{
                type: Output
            }], filteredResult: [{
                type: Output
            }], locationViewer: [{
                type: ViewChild,
                args: [NgxLocationViewerComponent, { static: false }]
            }], leafletSearchField: [{
                type: ViewChild,
                args: ["leafletSearch", { static: false }]
            }], onKeyCommand: [{
                type: HostListener,
                args: ["window:wheel", ["$event"]]
            }, {
                type: HostListener,
                args: ["window:keydown", ["$event"]]
            }] } });

var CrabAddressType;
(function (CrabAddressType) {
    CrabAddressType["SUB"] = "subadres";
    CrabAddressType["MAIN"] = "hoofdadres";
})(CrabAddressType || (CrabAddressType = {}));

var CascadingCoordinateRulesType;
(function (CascadingCoordinateRulesType) {
    CascadingCoordinateRulesType["LOCATION"] = "location";
    CascadingCoordinateRulesType["ADDRESS"] = "address";
})(CascadingCoordinateRulesType || (CascadingCoordinateRulesType = {}));

var LeafletTileLayerType;
(function (LeafletTileLayerType) {
    LeafletTileLayerType["DEFAULT"] = "default";
    LeafletTileLayerType["CUSTOM"] = "custom";
})(LeafletTileLayerType || (LeafletTileLayerType = {}));

function mapServiceFactory() {
    return new MapService('browser');
}
const MAP_SERVICE_PROVIDER = {
    provide: MapService,
    useFactory: mapServiceFactory
};

class LocationPickerModule {
}
/** @nocollapse */ LocationPickerModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: LocationPickerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
/** @nocollapse */ LocationPickerModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: LocationPickerModule, declarations: [NgxLocationPickerComponent,
        HighlightSearchDirective], imports: [HttpClientModule,
        FormsModule,
        CommonModule,
        ReactiveFormsModule,
        IconModule,
        LeafletModule,
        LocationViewerModule], exports: [NgxLocationPickerComponent] });
/** @nocollapse */ LocationPickerModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: LocationPickerModule, providers: [
        MAP_SERVICE_PROVIDER
    ], imports: [HttpClientModule,
        FormsModule,
        CommonModule,
        ReactiveFormsModule,
        IconModule,
        LeafletModule,
        LocationViewerModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: LocationPickerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        NgxLocationPickerComponent,
                        HighlightSearchDirective
                    ],
                    imports: [
                        HttpClientModule,
                        FormsModule,
                        CommonModule,
                        ReactiveFormsModule,
                        IconModule,
                        LeafletModule,
                        LocationViewerModule
                    ],
                    exports: [
                        NgxLocationPickerComponent,
                    ],
                    providers: [
                        MAP_SERVICE_PROVIDER
                    ]
                }]
        }] });

/*
 * Public API Surface of ngx-location-picker
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CascadingCoordinateRulesType, LeafletTileLayerType, LocationPickerModule, NgxLocationPickerComponent, NgxLocationPickerHelper, NgxLocationPickerService };
//# sourceMappingURL=acpaas-ui-widgets-ngx-location-picker.mjs.map
